@@ -3,11 +3,10 @@ package infra
 import (
 	"fmt"
 	"github.com/golang/protobuf/proto"
-	v2router "github.com/v2fly/v2ray-core/v4/app/router"
 	"github.com/v2fly/v2ray-core/v4/common/strmatcher"
+	"github.com/v2rayA/v2ray-lib/router/routercommon"
 	"github.com/v2rayA/v2rayA/core/v2ray/asset"
 	"os"
-	"path"
 	"regexp"
 	"sync"
 )
@@ -17,15 +16,18 @@ var whitelistCn struct {
 	sync.Mutex
 }
 
-func GetWhitelistCn(externDomains []*v2router.Domain) (wlDomains *strmatcher.MatcherGroup, err error) {
+func GetWhitelistCn(externDomains []*routercommon.Domain) (wlDomains *strmatcher.MatcherGroup, err error) {
 	whitelistCn.Lock()
 	defer whitelistCn.Unlock()
 	if whitelistCn.domainMatcher != nil {
 		return whitelistCn.domainMatcher, nil
 	}
-	dir := asset.GetV2rayLocationAsset()
-	var siteList v2router.GeoSiteList
-	b, err := os.ReadFile(path.Join(dir, "geosite.dat"))
+	datpath, err := asset.GetV2rayLocationAsset("geosite.dat")
+	if err != nil {
+		return nil, err
+	}
+	var siteList routercommon.GeoSiteList
+	b, err := os.ReadFile(datpath)
 	if err != nil {
 		return nil, fmt.Errorf("GetWhitelistCn: %w", err)
 	}
@@ -42,13 +44,13 @@ func GetWhitelistCn(externDomains []*v2router.Domain) (wlDomains *strmatcher.Mat
 			dms = append(dms, externDomains...)
 			for _, dm := range dms {
 				switch dm.Type {
-				case v2router.Domain_Domain:
+				case routercommon.Domain_RootDomain:
 					domainMatcher.Add(dm.Value)
-				case v2router.Domain_Full:
+				case routercommon.Domain_Full:
 					fullMatcher.Add(dm.Value)
-				case v2router.Domain_Plain:
+				case routercommon.Domain_Plain:
 					wlDomains.Add(SubstrMatcher(dm.Value))
-				case v2router.Domain_Regex:
+				case routercommon.Domain_Regex:
 					r, err := regexp.Compile(dm.Value)
 					if err != nil {
 						break
