@@ -12,7 +12,6 @@ import (
 	"github.com/v2rayA/v2rayA/common"
 	"github.com/v2rayA/v2rayA/common/netTools/netstat"
 	"github.com/v2rayA/v2rayA/common/netTools/ports"
-	"github.com/v2rayA/v2rayA/common/resolv"
 	"github.com/v2rayA/v2rayA/conf"
 	"github.com/v2rayA/v2rayA/core/coreObj"
 	"github.com/v2rayA/v2rayA/core/iptables"
@@ -353,7 +352,6 @@ func (t *Template) setDNS(outbounds []serverInfo, supportUDP map[string]bool) (r
 		}
 	}
 	domainsToLookup = common.Deduplicate(domainsToLookup)
-	var domainsToHosts []string
 	if len(domainsToLookup) > 0 {
 		var dnsList []string
 		if service.CheckTcpDnsSupported() == nil {
@@ -371,57 +369,29 @@ func (t *Template) setDNS(outbounds []serverInfo, supportUDP map[string]bool) (r
 		t.DNS.Servers = append(t.DNS.Servers, d...)
 		routing = append(routing, r...)
 	}
-	// set hosts
-	var wg sync.WaitGroup
-	var mu sync.Mutex
-	ech := make(chan error, len(domainsToHosts))
-	for _, domain := range domainsToHosts {
-		wg.Add(1)
-		go func(domain string) {
-			defer wg.Done()
-			ips, err := resolv.LookupHost(domain)
-			if err != nil {
-				ech <- fmt.Errorf("%w: please make sure you're connected to the Internet", err)
-				return
-			}
-			ips = FilterIPs(ips)
-			mu.Lock()
-			if t.DNS.Hosts == nil {
-				t.DNS.Hosts = make(coreObj.Hosts)
-			}
-			if service.CheckHostsListSupported() == nil {
-				t.DNS.Hosts[domain] = ips
-			} else {
-				t.DNS.Hosts[domain] = ips[0]
-			}
-			mu.Unlock()
-		}(domain)
-	}
-	wg.Wait()
-	select {
-	case err = <-ech:
-		return nil, err
-	default:
-		// deduplicate
-		strRouting := make([]string, 0, len(routing))
-		for _, r := range routing {
-			b, err := jsoniter.Marshal(r)
-			if err != nil {
-				log.Fatal("%v", err)
-			}
-			strRouting = append(strRouting, string(b))
+	// hard code for SNI problem like apple pushing
+	t.DNS.Hosts = make(coreObj.Hosts)
+	t.DNS.Hosts["courier.push.apple.com"] = []string{"1-courier.push.apple.com"}
+
+	// deduplicate
+	strRouting := make([]string, 0, len(routing))
+	for _, r := range routing {
+		b, err := jsoniter.Marshal(r)
+		if err != nil {
+			log.Fatal("%v", err)
 		}
-		strRouting = common.Deduplicate(strRouting)
-		routing = routing[:0]
-		for _, sr := range strRouting {
-			var r coreObj.RoutingRule
-			if err := jsoniter.Unmarshal([]byte(sr), &r); err != nil {
-				log.Fatal("%v: %v", err, sr)
-			}
-			routing = append(routing, r)
-		}
-		return routing, nil
+		strRouting = append(strRouting, string(b))
 	}
+	strRouting = common.Deduplicate(strRouting)
+	routing = routing[:0]
+	for _, sr := range strRouting {
+		var r coreObj.RoutingRule
+		if err := jsoniter.Unmarshal([]byte(sr), &r); err != nil {
+			log.Fatal("%v: %v", err, sr)
+		}
+		routing = append(routing, r)
+	}
+	return routing, nil
 }
 
 // FilterIPs returns filtered IP list.
@@ -497,6 +467,7 @@ func (t *Template) setDNSRouting(routing []coreObj.RoutingRule, supportUDP map[s
 					Type:        "field",
 					OutboundTag: "direct",
 					InboundTag: []string{
+						// do not worry the system proxy case.
 						"transparent",
 					},
 					Port: "53",
@@ -509,6 +480,13 @@ func (t *Template) setDNSRouting(routing []coreObj.RoutingRule, supportUDP map[s
 
 func (t *Template) AppendRoutingRuleByMode(mode configure.RulePortMode, inbounds []string) (err error) {
 	firstOutboundTag, _ := t.FirstProxyOutboundName(nil)
+	// apple pushing. #495 #479
+	t.Routing.Rules = append(t.Routing.Rules, coreObj.RoutingRule{
+		Type:        "field",
+		OutboundTag: "direct",
+		InboundTag:  deepcopy.Copy(inbounds).([]string),
+		Domain:      []string{"domain:push-apple.com.akadns.net", "domain:push.apple.com"},
+	})
 	switch mode {
 	case configure.WhitelistMode:
 		// foreign domains with intranet IP should be proxied first rather than directly connected
@@ -689,6 +667,20 @@ func parseRoutingA(t *Template, routingInboundTags []string) error {
 									DestOverride: []string{"http", "tls"},
 								},
 							}
+							if sniffing := proto.NamedParams["sniffing"]; len(sniffing) > 0 {
+								// support inbound:a=socks(address: 127.0.0.1, port: 1080, sniffing:tls, sniffing:http)
+								// support inbound:a=http(address: 127.0.0.1, port: 1081, sniffing:"http,tls")
+								in.Sniffing.Enabled = true
+								var sniffs []string
+								for _, sniff := range sniffing {
+									fields := strings.Split(sniff, ",")
+									for i := range fields {
+										fields[i] = strings.TrimSpace(fields[i])
+									}
+									sniffs = append(sniffs, fields...)
+								}
+								in.Sniffing.DestOverride = sniffs
+							}
 							if proto.Name == "socks" {
 								if len(server.Users) > 0 {
 									in.Settings.Auth = "password"
@@ -812,12 +804,16 @@ func parseRoutingA(t *Template, routingInboundTags []string) error {
 }
 
 func (t *Template) setTransparentRouting() (err error) {
+	tproxyInbounds := []string{"transparent"}
+	if t.Setting.TransparentType == configure.TransparentSystemProxy {
+		tproxyInbounds = append(tproxyInbounds, "transparent2")
+	}
 	switch t.Setting.Transparent {
 	case configure.TransparentProxy:
 	case configure.TransparentWhitelist:
-		return t.AppendRoutingRuleByMode(configure.WhitelistMode, []string{"transparent"})
+		return t.AppendRoutingRuleByMode(configure.WhitelistMode, tproxyInbounds)
 	case configure.TransparentGfwlist:
-		return t.AppendRoutingRuleByMode(configure.GfwlistMode, []string{"transparent"})
+		return t.AppendRoutingRuleByMode(configure.GfwlistMode, tproxyInbounds)
 	case configure.TransparentFollowRule:
 		// transparent mode is the same as rule
 		for i := range t.Routing.Rules {
@@ -829,7 +825,7 @@ func (t *Template) setTransparentRouting() (err error) {
 				}
 			}
 			if ok {
-				t.Routing.Rules[i].InboundTag = append(t.Routing.Rules[i].InboundTag, "transparent")
+				t.Routing.Rules[i].InboundTag = append(t.Routing.Rules[i].InboundTag, tproxyInbounds...)
 			}
 		}
 	}
@@ -976,6 +972,8 @@ func (t *Template) appendDNSOutbound() {
 	t.Outbounds = append(t.Outbounds, coreObj.OutboundObject{
 		Tag:      "dns-out",
 		Protocol: "dns",
+		// Fallback DNS for non-A/AAAA/CNAME requests. https://github.com/v2rayA/v2rayA/issues/188
+		Settings: coreObj.Settings{Address: "119.29.29.29", Port: 53, Network: "udp"},
 	})
 }
 
@@ -1050,6 +1048,12 @@ func (t *Template) setInbound() error {
 				Listen:   "127.0.0.1",
 				Tag:      "transparent",
 			})
+			t.Inbounds = append(t.Inbounds, coreObj.Inbound{
+				Port:     32346,
+				Protocol: "socks",
+				Listen:   "127.0.0.1",
+				Tag:      "transparent2",
+			})
 		}
 
 	}
@@ -1063,6 +1067,9 @@ func (t *Template) setInbound() error {
 				Listen:   "0.0.0.0",
 				Settings: &coreObj.InboundSettings{
 					Network: "udp",
+					// the non-A/AAAA/CNAME problem has been fixed by the setting in DNS outbound.
+					// so the Address here is innocuous.
+					// related commit: https://github.com/v2rayA/v2rayA/commit/ecbf915d4be8b9066955a21059519266bcca6b92
 					Address: "2.0.1.7",
 					Port:    53,
 				},
@@ -1135,60 +1142,14 @@ func (t *Template) setWhitelistRouting(whitelist []Addr) {
 	}
 }
 
-func (t *Template) setGroupRouting(serverData *ServerData) (err error) {
+func (t *Template) setGroupRouting() {
 	outbounds := t.outNames()
-	mSubjectSelector := make(map[string]struct{})
-	for outbound, isGroup := range outbounds {
-		if !isGroup {
-			continue
-		}
-
-		strategy := "leastPing"
-		interval := 10 * time.Second
-		var selector []string
-
-		for _, vi := range serverData.OutboundName2ServerObjs[outbound] {
-			selector = append(selector, Ps2OutboundTag(vi.GetName()))
-		}
-
-		t.Routing.Balancers = append(t.Routing.Balancers, coreObj.Balancer{
-			Tag:      outbound,
-			Selector: selector,
-			Strategy: coreObj.BalancerStrategy{
-				//TODO: configure.GetOutboundSetting
-				Type: strategy,
-			},
-		})
-
-		if strategy == "leastPing" {
-			if err = service.CheckObservatorySupported(); err != nil {
-				return fmt.Errorf("not support observatory based load balance: %w", err)
-			}
-			if t.Observatory == nil {
-				t.Observatory = &coreObj.Observatory{
-					ProbeURL:      "https://gstatic.com/generate_204",
-					ProbeInterval: interval.String(),
-				}
-			}
-			for _, s := range selector {
-				mSubjectSelector[s] = struct{}{}
-			}
-		}
-	}
-	if t.Observatory != nil {
-		var subjectSelector []string
-		for s := range mSubjectSelector {
-			subjectSelector = append(subjectSelector, s)
-		}
-		t.Observatory.SubjectSelector = subjectSelector
-	}
 	for i := range t.Routing.Rules {
 		if t.Routing.Rules[i].OutboundTag != "" &&
 			outbounds[t.Routing.Rules[i].OutboundTag] == true {
 			t.Routing.Rules[i].BalancerTag, t.Routing.Rules[i].OutboundTag = t.Routing.Rules[i].OutboundTag, ""
 		}
 	}
-	return nil
 }
 
 type ServerData struct {
@@ -1411,7 +1372,7 @@ func (t *Template) resolveOutbounds(
 	return supportUDP, outboundTags, nil
 }
 
-func (t *Template) SetAPI() (port int) {
+func (t *Template) SetAPI(serverData *ServerData) (port int, err error) {
 	services := []string{
 		"LoggerService",
 	}
@@ -1424,9 +1385,56 @@ func (t *Template) SetAPI() (port int) {
 		}
 		time.Sleep(100 * time.Millisecond)
 	}
-	if t.Observatory != nil {
-		services = append(services, "ObservatoryService")
-		t.ApiCloses = append(t.ApiCloses, ObservatoryProducer(port))
+	if serverData != nil {
+		outbounds := t.outNames()
+		mSubjectSelector := make(map[string]struct{})
+		for outbound, isGroup := range outbounds {
+			if !isGroup {
+				continue
+			}
+
+			strategy := "leastPing"
+			interval := 10 * time.Second
+			var selector []string
+
+			for _, vi := range serverData.OutboundName2ServerObjs[outbound] {
+				selector = append(selector, Ps2OutboundTag(vi.GetName()))
+			}
+
+			t.Routing.Balancers = append(t.Routing.Balancers, coreObj.Balancer{
+				Tag:      outbound,
+				Selector: selector,
+				Strategy: coreObj.BalancerStrategy{
+					//TODO: configure.GetOutboundSetting
+					Type: strategy,
+				},
+			})
+
+			if strategy == "leastPing" {
+				if err = service.CheckObservatorySupported(); err != nil {
+					return port, fmt.Errorf("not support observatory based load balance: %w", err)
+				}
+				if t.Observatory == nil {
+					t.Observatory = &coreObj.Observatory{
+						ProbeURL:      "https://gstatic.com/generate_204",
+						ProbeInterval: interval.String(),
+					}
+				}
+				for _, s := range selector {
+					mSubjectSelector[s] = struct{}{}
+				}
+			}
+		}
+		if t.Observatory != nil {
+			var subjectSelector []string
+			for s := range mSubjectSelector {
+				subjectSelector = append(subjectSelector, s)
+			}
+			t.Observatory.SubjectSelector = subjectSelector
+
+			services = append(services, "ObservatoryService")
+			t.ApiCloses = append(t.ApiCloses, ObservatoryProducer(port))
+		}
 	}
 	t.API = &coreObj.APIObject{
 		Tag:      "api-out",
@@ -1448,7 +1456,7 @@ func (t *Template) SetAPI() (port int) {
 		OutboundTag: "api-out",
 	})
 	t.ApiPort = port
-	return port
+	return port, nil
 }
 
 func (t *Template) setVlessGrpcRouting() {
@@ -1537,19 +1545,14 @@ func NewTemplate(serverInfos []serverInfo, setting *configure.Setting) (t *Templ
 			return nil, err
 		}
 	}
-	//set group routing
-	if err = t.setGroupRouting(serverData); err != nil {
-		return nil, err
-	}
 	//set vlessGrpc routing
 	t.setVlessGrpcRouting()
 	// set api
 	if t.API == nil {
-		t.SetAPI()
+		if _, err = t.SetAPI(serverData); err != nil {
+			return nil, err
+		}
 	}
-	// set spare tire outbound. Fix: https://github.com/v2rayA/v2rayA/issues/447
-	t.Routing.Rules = append(t.Routing.Rules, coreObj.RoutingRule{Type: "field", Network: "tcp,udp", OutboundTag: "proxy"})
-
 	// set routing whitelist
 	var whitelist []Addr
 	for _, info := range serverInfos {
@@ -1566,6 +1569,12 @@ func NewTemplate(serverInfos []serverInfo, setting *configure.Setting) (t *Templ
 
 	t.updatePrivateRouting()
 
+	// add spare tire outbound routing. Fix: https://github.com/v2rayA/v2rayA/issues/447
+	t.Routing.Rules = append(t.Routing.Rules, coreObj.RoutingRule{Type: "field", Network: "tcp,udp", OutboundTag: "proxy"})
+
+	// Set group routing. This should be put in the end of routing setters.
+	t.setGroupRouting()
+
 	t.optimizeGeoipMemoryOccupation()
 
 	//set outboundSockopt
