@@ -1,11 +1,12 @@
 package controller
 
 import (
+	"fmt"
 	"github.com/gin-gonic/gin"
 	"github.com/v2rayA/v2rayA/common"
 	"github.com/v2rayA/v2rayA/db/configure"
+	"github.com/v2rayA/v2rayA/pkg/util/log"
 	"github.com/v2rayA/v2rayA/server/service"
-	"log"
 )
 
 func PostConnection(ctx *gin.Context) {
@@ -26,13 +27,13 @@ func PostConnection(ctx *gin.Context) {
 	var which configure.Which
 	err := ctx.ShouldBindJSON(&which)
 	if err != nil {
-		common.ResponseError(ctx, logError(nil, "bad request"))
+		common.ResponseError(ctx, logError("bad request"))
 		return
 	}
 	err = service.Connect(&which)
 	if err != nil {
-		log.Println(err)
-		common.ResponseError(ctx, logError(err, "failed to connect"))
+		log.Warn("PostConnection: %v", err)
+		common.ResponseError(ctx, logError(fmt.Errorf("failed to connect: %w", err)))
 		return
 	}
 	getTouch(ctx)
@@ -56,7 +57,7 @@ func DeleteConnection(ctx *gin.Context) {
 	var which configure.Which
 	err := ctx.ShouldBindJSON(&which)
 	if err != nil {
-		common.ResponseError(ctx, logError(nil, "bad request"))
+		common.ResponseError(ctx, logError("bad request"))
 		return
 	}
 	err = service.Disconnect(which, false)
@@ -84,7 +85,7 @@ func PostV2ray(ctx *gin.Context) {
 
 	err := service.StartV2ray()
 	if err != nil {
-		common.ResponseError(ctx, logError(err, "failed to start v2ray-core"))
+		common.ResponseError(ctx, logError(fmt.Errorf("failed to start v2ray-core: %w", err)))
 		return
 	}
 	getTouch(ctx)
@@ -107,7 +108,7 @@ func DeleteV2ray(ctx *gin.Context) {
 
 	err := service.StopV2ray()
 	if err != nil {
-		common.ResponseError(ctx, logError(err, "failed to stop v2ray-core"))
+		common.ResponseError(ctx, logError(fmt.Errorf("failed to stop v2ray-core: %w", err)))
 		return
 	}
 	getTouch(ctx)
