@@ -10,7 +10,7 @@ import (
 )
 
 func CheckUpdate() (foundNew bool, remoteVersion string, err error) {
-	resp, err := http.Get("https://apt.v2raya.mzz.pub/dists/v2raya/main/binary-amd64/Packages")
+	resp, err := http.Get("https://apt.v2raya.org/dists/v2raya/main/binary-amd64/Packages")
 	if err != nil {
 		return
 	}
